@@ -107,7 +107,20 @@ def get_handler(id_or_link, project=None):
     except Exception as e:
         raise DXError("Could not parse link {}: {}".format(id_or_link, e))
 
-    if project is None or cls in [dxpy.DXJob, dxpy.DXAnalysis, dxpy.DXProject, dxpy.DXContainer]:
+    if cls == dxpy.DXApp:
+        # This special case should translate identifiers of the form
+        # "app-name" or "app-name/version_or_tag" to the appropriate
+        # arguments
+        if dxpy.utils.resolver.is_hashid(id_or_link):
+            return cls(id_or_link)
+        else:
+            slash_pos = id_or_link.find('/')
+            if slash_pos == -1:
+                return cls(name=id_or_link[4:])
+            else:
+                return cls(name=id_or_link[4:slash_pos],
+                           alias=id_or_link[slash_pos + 1:])
+    elif project is None or cls in [dxpy.DXJob, dxpy.DXAnalysis, dxpy.DXProject, dxpy.DXContainer]:
         # This case is important for the handlers which do not
         # take a project field
         return cls(id_or_link)
